# Author: Logan Tucker
# Date: 11.8.21
# Purpose: Sort a list of cities by name, latitude, and population. Write each sorted list into their own files


from city import City
from quicksort import sort


# Purpose: read in and parse the input file. Make a list of City objects
# parameters: (file_name) a string representing the file to read from
def read(file_name):
    clist = []
    in_file = open(file_name, "r")

    for line in in_file:
        city_information = line.split(",")  # make each line into a list of info

        # make each list of info into a city object
        c = City(city_information[0], city_information[1], city_information[2], int(city_information[3]),
                 float(city_information[4]), float(city_information[5]))

        clist.append(c)

    in_file.close()
    return clist


# Purpose: Write the information from a list of City objects into an out file
# Parameters: (clist) a list of city objects, and (file_name) the name of the out file
def write(clist, file_name):
    out_file = open(file_name, "w")

    for c in clist:
        city = str(c)
        out_file.write(city + "\n")

    out_file.close()


# Purpose: Compare two cities name's by alphabetical order
# Parameters: (a, b) each is a string and the name of a city
def compare_name(a, b):
    return a.name.lower() <= b.name.lower()


# Purpose: Compare two cities population's
# Parameters: (a, b) each is an int and the population of a city
def compare_pop(a, b):
    return a.population >= b.population


# Purpose: Compare two cities latitude's
# Parameters: (a, b) each is a float and the latitude of a city
def compare_lat(a, b):
    return a.latitude <= b.latitude


# Purpose: Sort a list of cities by alphabetical order
# Parameters: (clist) a list of city objects
def alpha_sort(clist):
    sort(clist, compare_name)


# Purpose: Sort a list of cities by population
# Parameters: (clist) a list of city objects
def pop_sort(clist):
    sort(clist, compare_pop)


# Purpose: Sort a list of cities by latitude
# Parameters: (clist) a list of city objects
def lat_sort(clist):
    sort(clist, compare_lat)


# Purpose: Sort a list of city information by alphabetical order, population and latitude and write each result into
# a separate file
# Parameters: None
def main():
    clist = read("world_cities.txt")

    alpha_sort(clist)
    write(clist, "cities_alpha.txt")

    pop_sort(clist)
    write(clist, "cities_population.txt")

    lat_sort(clist)
    write(clist, "cities_latitude.txt")


main()






